# python imports
from datetime import datetime
import os

# django imports
from django.conf import settings
from django.contrib.comments.moderation import CommentModerator, moderator
from django.core.urlresolvers import reverse
from django.db import models

# other imports
from photologue.models import Gallery, Photo

# Get relative media path
try:
    PRESSROOM_DIR = settings.PRESSROOM_DIR
except:
    PRESSROOM_DIR = 'pressroom'

# define the models
class ArticleManager(models.Manager):
    def get_published(self):
        return self.filter(publish=True, pub_date__lte=datetime.now)
    def get_drafts(self):
        return self.filter(publish=False)

class Article(models.Model):
    pub_date = models.DateTimeField("Publish date", default=datetime.now)
    headline = models.CharField(max_length=200)
    slug = models.SlugField(help_text='A "Slug" is a unique URL-friendly title for an object.')
    summary = models.TextField(help_text="A single paragraph summary or preview of the article.")
    body = models.TextField("Body text")
    author = models.CharField(max_length=100)
    publish = models.BooleanField("Publish on site", default=True,
                                  help_text='Articles will not appear on the site until their "publish date".')
    sections = models.ManyToManyField('Section', related_name='articles')
    photos = models.ManyToManyField(Photo, related_name='articles', null=True, blank=True)
    documents = models.ManyToManyField('Document', related_name='articles', null=True, blank=True)
    enable_comments = models.BooleanField(default=True)

    # Custom article manager
    objects = ArticleManager()

    class Meta:
        ordering = ['-pub_date']
        get_latest_by = 'pub_date'
    
    def __unicode__(self):
        return self.headline

    def get_absolute_url(self):
        args = self.pub_date.strftime("%Y/%b/%d").lower().split("/") + [self.slug]
        return reverse('pr-article-detail', args=args)

class ArticleCommentModerator(CommentModerator):
    email_notification = True
    enable_field = 'enable_comments'
    
    def moderate(self, comment, content_object, request):
        return True

if Article not in moderator._registry:
    moderator.register(Article, ArticleCommentModerator)

class Document(models.Model):
    file = models.FileField("Document", upload_to=PRESSROOM_DIR+"/documents/%Y/%b/%d")
    pub_date = models.DateTimeField("Date published", default=datetime.now)
    title = models.CharField(max_length=200)
    slug = models.SlugField()
    summary = models.TextField()

    class Meta:
        ordering = ['-pub_date']
        get_latest_by = 'pub_date'

    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        args = self.pub_date.strftime("%Y/%b/%d").lower().split("/") + [self.slug]
        return reverse('pr-document-detail', args=args)
    
    def doc_dir(self):
        doc_dir = None
        if self.file is not None:
            doc_dir = os.path.dirname(self.file.path) 
        return doc_dir

    def delete(self):
        doc_dir = self.doc_dir()
        super(Document, self).delete()
        if doc_dir is not None:
            if os.listdir(doc_dir) == []:
                    os.removedirs(doc_dir)

class Section(models.Model):
    title = models.CharField(max_length=80, unique=True)
    slug = models.SlugField()

    class Meta:
        ordering = ['title']

    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        return reverse('pr-section', args=[self.slug])



import os
DIRNAME = os.path.dirname(__file__)
DEBUG=True
DATABASE_ENGINE = 'sqlite3'
DATABASE_NAME = '/tmp/pressroom.db'

MEDIA_ROOT = os.path.realpath(os.path.join(DIRNAME, 'tests', 'media/'))
MEDIA_URL = '/site_media/'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    os.path.join(DIRNAME, "tests", "templates"),
)
INSTALLED_APPS = ['django.contrib.admin',
                  'django.contrib.auth',
                  'django.contrib.contenttypes',
                  'django.contrib.sessions',
                  'photologue',
                  'pressroom', ]
ROOT_URLCONF = 'pressroom.tests.urls'



from django.conf import settings
from django.conf.urls.defaults import *
from pressroom.models import *
from pressroom.feeds import LatestEntries


try:
    MAKE_ARTICLE_OBJECT_LIST = settings.PRESSROOM_MAKE_ARTICLE_OBJECT_LIST
except:
    MAKE_ARTICLE_OBJECT_LIST = False

try:
    MAKE_DOCUMENT_OBJECT_LIST = settings.PRESSROOM_MAKE_DOCUMENT_OBJECT_LIST
except:
    MAKE_DOCUMENT_OBJECT_LIST = False

# custom views
urlpatterns = patterns('pressroom.views',
    url(r'^$', 'index', name="pr-index"),
    url(r'^section/(?P<slug>[\-\d\w]+)/$', 'view_section', name="pr-section"),
    url(r'^section/(?P<slug>[\-\d\w]+)/page/(?P<page>[0-9]+)/$', 'view_section', name="pr-section-page"),
    url(r'^article/page/(?P<page>[0-9]+)/$', 'article_list', name='pr-article-list'),
)

# articles
article_args = {'date_field': 'pub_date', 'allow_empty': True, 'queryset': Article.objects.get_published()}
if MAKE_ARTICLE_OBJECT_LIST:
    year_article_args = dict(article_args, make_object_list=True)
else:
    year_article_args = article_args

urlpatterns += patterns('django.views.generic.date_based',
    url(r'^article/(?P<year>\d{4})/(?P<month>[a-z]{3})/(?P<day>\w{1,2})/(?P<slug>[\-\d\w]+)/$', 'object_detail', {'date_field': 'pub_date', 'slug_field': 'slug', 'queryset': Article.objects.all()}, name='pr-article-detail'),
    url(r'^article/(?P<year>\d{4})/(?P<month>[a-z]{3})/(?P<day>\w{1,2})/$', 'archive_day', article_args, name='pr-article-archive-day'),
    url(r'^article/(?P<year>\d{4})/(?P<month>[a-z]{3})/$', 'archive_month', article_args, name='pr-article-archive-month'),
    url(r'^article/(?P<year>\d{4})/$', 'archive_year', year_article_args, name='pr-article-archive-year'),
    url(r'^article/$', 'archive_index', article_args, name='pr-article-archive'),
)

# documents
document_args = {'date_field': 'pub_date', 'allow_empty': True, 'queryset': Document.objects.all()}
if MAKE_ARTICLE_OBJECT_LIST:
    year_document_args = dict(document_args, make_object_list=True)
else:
    year_document_args = document_args
urlpatterns += patterns('django.views.generic.date_based',
    url(r'^document/(?P<year>\d{4})/(?P<month>[a-z]{3})/(?P<day>\w{1,2})/(?P<slug>[\-\d\w]+)/$', 'object_detail', {'date_field': 'pub_date', 'slug_field': 'slug', 'queryset': Document.objects.all()}, name='pr-document-detail'),
    url(r'^document/(?P<year>\d{4})/(?P<month>[a-z]{3})/(?P<day>\w{1,2})/$', 'archive_day', document_args, name='pr-document-archive-day'),
    url(r'^document/(?P<year>\d{4})/(?P<month>[a-z]{3})/$', 'archive_month', document_args, name='pr-document-archive-month'),
    url(r'^document/(?P<year>\d{4})/$', 'archive_year', year_document_args, name='pr-document-archive-year'),
    url(r'^document/$', 'archive_index', document_args, name='pr-document-archive'),
)
urlpatterns += patterns('django.views.generic.list_detail',
    url(r'^document/page/(?P<page>[0-9]+)/$', 'object_list', {'queryset': Document.objects.all(), 'allow_empty': True, 'paginate_by': 20}, name='pr-document-list'),
)

feeds = {
    'rss': LatestEntries,
}

urlpatterns += patterns('',
    url(r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.feed',  {'feed_dict': feeds}, name="pr-rss"),
)




from datetime import datetime

from django.template.context import RequestContext
from django.views.generic import list_detail
from django.shortcuts import render_to_response, get_object_or_404

from pressroom.models import Article, Section


def index(request):
    articles = Article.objects.get_published()[:5]
    try:
        from photologue.models import Gallery
        galleries = Gallery.objects.all()[:3]
    except:
        pass
    return render_to_response('pressroom/index.html', locals(),
                              context_instance=RequestContext(request))


def view_section(request, slug, page=1):
    section = get_object_or_404(Section, slug=slug)
    articles = section.articles.filter(publish=True, pub_date__lte=datetime.now())
    try:
        from photologue.models import Gallery
        galleries = Gallery.objects.all()[:3]
    except:
        galleries = None
    return list_detail.object_list(request,
                                   queryset=articles,
                                   paginate_by=5,
                                   page=page,
                                   allow_empty=True,
                                   template_name='pressroom/view_section.html',
                                   extra_context={'section': section,
                                                  'galleries': Gallery.objects.all()[:3]})

def article_list(request, page=0):
    return list_detail.object_list(request=request,
                                   queryset=Article.objects.get_published(),
                                   allow_empty=True,
                                   paginate_by=5,
                                   page=page)



from django.contrib import admin
from models import Article, Document, Section

class ArticleAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('headline',)}
    list_display = ('headline', 'author', 'pub_date', 'publish')
    list_filter = ['pub_date']
    date_hierarchy = 'pub_date'
    save_as = True
    
class DocumentAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('title',)}
    list_display = ('title', 'pub_date')
    list_filter = ['pub_date']

class SectionAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('title',)}
    list_display = ('title',)

admin.site.register(Article, ArticleAdmin)
admin.site.register(Document, DocumentAdmin)
admin.site.register(Section, SectionAdmin)
    




from south.db import db
from django.db import models
from pressroom.models import *

class Migration:
    
    def forwards(self, orm):
        
        # Adding model 'Article'
        db.create_table('pressroom_article', (
            ('id', models.AutoField(primary_key=True)),
            ('pub_date', models.DateTimeField("Publish date", default=datetime.datetime.now)),
            ('headline', models.CharField(max_length=200)),
            ('slug', models.SlugField()),
            ('summary', models.TextField(blank=True)),
            ('body', models.TextField("Body text")),
            ('author', models.CharField(max_length=100)),
            ('publish', models.BooleanField("Publish on site", default=True)),
        ))
        db.send_create_signal('pressroom', ['Article'])
        
        # Adding model 'Section'
        db.create_table('pressroom_section', (
            ('id', models.AutoField(primary_key=True)),
            ('title', models.CharField(unique=True, max_length=80)),
            ('slug', models.SlugField()),
        ))
        db.send_create_signal('pressroom', ['Section'])
        
        # Adding model 'Document'
        db.create_table('pressroom_document', (
            ('id', models.AutoField(primary_key=True)),
            ('file', models.FileField("Document")),
            ('pub_date', models.DateTimeField("Date published", default=datetime.datetime.now)),
            ('title', models.CharField(max_length=200)),
            ('slug', models.SlugField()),
            ('summary', models.TextField()),
        ))
        db.send_create_signal('pressroom', ['Document'])
        
        # Adding ManyToManyField 'Article.documents'
        db.create_table('pressroom_article_documents', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('article', models.ForeignKey(orm.Article, null=False)),
            ('document', models.ForeignKey(orm.Document, null=False))
        ))
        
        # Adding ManyToManyField 'Article.photos'
        db.create_table('pressroom_article_photos', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('article', models.ForeignKey(orm.Article, null=False)),
            ('photo', models.ForeignKey(orm['photologue.Photo'], null=False))
        ))
        
        # Adding ManyToManyField 'Article.sections'
        db.create_table('pressroom_article_sections', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('article', models.ForeignKey(orm.Article, null=False)),
            ('section', models.ForeignKey(orm.Section, null=False))
        ))
        
    
    
    def backwards(self, orm):
        
        # Deleting model 'Article'
        db.delete_table('pressroom_article')
        
        # Deleting model 'Section'
        db.delete_table('pressroom_section')
        
        # Deleting model 'Document'
        db.delete_table('pressroom_document')
        
        # Dropping ManyToManyField 'Article.documents'
        db.delete_table('pressroom_article_documents')
        
        # Dropping ManyToManyField 'Article.photos'
        db.delete_table('pressroom_article_photos')
        
        # Dropping ManyToManyField 'Article.sections'
        db.delete_table('pressroom_article_sections')
        
    
    
    models = {
        'pressroom.article': {
            'Meta': {'ordering': "['-pub_date']", 'get_latest_by': "'pub_date'"},
            'author': ('models.CharField', [], {'max_length': '100'}),
            'body': ('models.TextField', ['"Body text"'], {}),
            'documents': ('models.ManyToManyField', ["orm['pressroom.Document']"], {'related_name': "'articles'", 'null': 'True', 'blank': 'True'}),
            'headline': ('models.CharField', [], {'max_length': '200'}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'photos': ('models.ManyToManyField', ["orm['photologue.Photo']"], {'related_name': "'articles'", 'null': 'True', 'blank': 'True'}),
            'pub_date': ('models.DateTimeField', ['"Publish date"'], {'default': 'datetime.datetime.now'}),
            'publish': ('models.BooleanField', ['"Publish on site"'], {'default': 'True'}),
            'sections': ('models.ManyToManyField', ["orm['pressroom.Section']"], {'related_name': "'articles'"}),
            'slug': ('models.SlugField', [], {}),
            'summary': ('models.TextField', [], {'blank': 'True'})
        },
        'photologue.photo': {
            'Meta': {'ordering': "['-date_added']", 'get_latest_by': "'date_added'"},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'pressroom.section': {
            'Meta': {'ordering': "['title']"},
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'slug': ('models.SlugField', [], {}),
            'title': ('models.CharField', [], {'unique': 'True', 'max_length': '80'})
        },
        'pressroom.document': {
            'Meta': {'ordering': "['-pub_date']", 'get_latest_by': "'pub_date'"},
            'file': ('models.FileField', ['"Document"'], {}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'pub_date': ('models.DateTimeField', ['"Date published"'], {'default': 'datetime.datetime.now'}),
            'slug': ('models.SlugField', [], {}),
            'summary': ('models.TextField', [], {}),
            'title': ('models.CharField', [], {'max_length': '200'})
        }
    }
    
    complete_apps = ['pressroom']



from django.conf.urls.defaults import *
from django.conf import settings

from django.contrib import admin
admin.autodiscover()

import os
DIRNAME = os.path.dirname(__file__)

urlpatterns = patterns("",
    (r'', include('pressroom.urls')),
)

urlpatterns += patterns("",
    (r'^admin/(.*)', admin.site.root),
    (r'^site_media/(?P<path>.*)$', 'django.views.static.serve', {'document_root': os.path.join(DIRNAME, "media"), 'show_indexes': True }),
)


import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "django-pressroom",
    version = "0.4",
    url = 'http://code.google.com/p/django-pressroom/',
    license = 'BSD',
    description = "A pressroom application for django.",
    long_description = read('README'),

    author = 'Justin Driscoll, Michael Thornhill',
    author_email = 'michael@maithu.com',

    packages = find_packages('src'),
    package_dir = {'': 'src'},

    install_requires = ['setuptools', 'django-photologue'],

    classifiers = [
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)




from south.db import db
from django.db import models
from pressroom.models import *

class Migration:
    
    def forwards(self, orm):
        
        # Adding field 'Article.enable_comments'
        db.add_column('pressroom_article', 'enable_comments', models.BooleanField(default=True))
        
    
    
    def backwards(self, orm):
        
        # Deleting field 'Article.enable_comments'
        db.delete_column('pressroom_article', 'enable_comments')
        
    
    
    models = {
        'pressroom.article': {
            'Meta': {'ordering': "['-pub_date']", 'get_latest_by': "'pub_date'"},
            'author': ('models.CharField', [], {'max_length': '100'}),
            'body': ('models.TextField', ['"Body text"'], {}),
            'documents': ('models.ManyToManyField', ["orm['pressroom.Document']"], {'related_name': "'articles'", 'null': 'True', 'blank': 'True'}),
            'enable_comments': ('models.BooleanField', [], {'default': 'True'}),
            'headline': ('models.CharField', [], {'max_length': '200'}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'photos': ('models.ManyToManyField', ["orm['photologue.Photo']"], {'related_name': "'articles'", 'null': 'True', 'blank': 'True'}),
            'pub_date': ('models.DateTimeField', ['"Publish date"'], {'default': 'datetime.datetime.now'}),
            'publish': ('models.BooleanField', ['"Publish on site"'], {'default': 'True'}),
            'sections': ('models.ManyToManyField', ["orm['pressroom.Section']"], {'related_name': "'articles'"}),
            'slug': ('models.SlugField', [], {}),
            'summary': ('models.TextField', [], {})
        },
        'photologue.photo': {
            'Meta': {'ordering': "['-date_added']", 'get_latest_by': "'date_added'"},
            '_stub': True,
            'id': ('models.AutoField', [], {'primary_key': 'True'})
        },
        'pressroom.section': {
            'Meta': {'ordering': "['title']"},
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'slug': ('models.SlugField', [], {}),
            'title': ('models.CharField', [], {'unique': 'True', 'max_length': '80'})
        },
        'pressroom.document': {
            'Meta': {'ordering': "['-pub_date']", 'get_latest_by': "'pub_date'"},
            'file': ('models.FileField', ['"Document"'], {}),
            'id': ('models.AutoField', [], {'primary_key': 'True'}),
            'pub_date': ('models.DateTimeField', ['"Date published"'], {'default': 'datetime.datetime.now'}),
            'slug': ('models.SlugField', [], {}),
            'summary': ('models.TextField', [], {}),
            'title': ('models.CharField', [], {'max_length': '200'})
        }
    }
    
    complete_apps = ['pressroom']



from django.contrib.syndication.feeds import Feed
from models import Article

class LatestEntries(Feed):
    title = "Latest News"
    link = "/news/"
    description = "Updates on changes and additions"

    def items(self):
        return Article.objects.get_published().order_by('-pub_date')[:5]
